@@ -66,6 +66,17 @@ def check_value(value, default):
     return value
 
 
+def fill(value, length, char: str, position="font"):
+    value = str(value)
+    value_len = len(value)
+    if len(value) < length:
+        if position == "font":
+            value = char * (length - value_len) + value
+        else:
+            value = value + char * (length - value_len)
+    return value
+
+
 def check_or_add_growth_rate(data: List[dict], value_key: str, growth_rate_key: str = "growth_rate",
                              start_growth_rate: float = None, pre_value: Union[int, float] = None, flag: bool = True,
                              digits: int = None):
